Method: Timber::Config#http_body_limit
- Defined in:
- lib/timber/config.rb
#http_body_limit ⇒ Object
Truncates captured HTTP bodies to this specified limit. The default is 2000. If you want to capture more data, you can raise this to a maximum of 5000, or lower this to be more efficient with data. 2000 characters should give you a good idea of the body content. If you need to raise to 5000 you’re only constraint is network throughput.
103 104 105 |
# File 'lib/timber/config.rb', line 103 def http_body_limit @http_body_limit end |